@@ -16,7 +16,7 @@ use Readonly;
 
 Readonly::Scalar our $DR => 'dwgread';
 
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 # Constructor.
 sub new {
@@ -36,16 +36,18 @@ sub run {
 	# Process arguments.
 	$self->{'_opts'} = {
 		'd' => undef,
+		'f' => 0,
 		'h' => 0,
 		'i' => 0,
 		'm' => undef,
 		'v' => 1,
 	};
-	if (! getopts('d:him:v:', $self->{'_opts'}) || @ARGV < 1
+	if (! getopts('d:fhim:v:', $self->{'_opts'}) || @ARGV < 1
 		|| $self->{'_opts'}->{'h'}) {
 
-		print STDERR "Usage: $0 [-d test_dir] [-h] [-i] [-m match_string] [-v level] [--version] directory\n";
+		print STDERR "Usage: $0 [-d test_dir] [-f] [-h] [-i] [-m match_string] [-v level] [--version] directory\n";
 		print STDERR "\t-d test_dir\tTest directory (default is directory in system tmp).\n";
+		print STDERR "\t-f\t\tPrint file.\n";
 		print STDERR "\t-h\t\tPrint help.\n";
 		print STDERR "\t-i\t\tIgnore errors.\n";
 		print STDERR "\t-m match_string\tMatch string (default is not defined).\n";
@@ -97,8 +99,10 @@ sub _exec {
 	};
 
 	if ($exit_code) {
-		print STDERR "Cannot dwgread '$dwg_file'.\n";
-		print STDERR "\tCommand '$command' exit with $exit_code.\n";
+		if (! $self->{'_opts'}->{'i'}) {
+			print STDERR "Cannot dwgread '$dwg_file'.\n";
+			print STDERR "\tCommand '$command' exit with $exit_code.\n";
+		}
 		return;
 	}
 
@@ -121,6 +125,9 @@ sub _exec {
 
 		if (defined $self->{'_opts'}->{'m'}) {
 			foreach my $match_line ($self->_match_lines($stderr)) {
+				if ($self->{'_opts'}->{'f'}) {
+					print $dwg_file.': ';
+				}
 				print $match_line."\n";
 			}
 		}
@@ -242,12 +249,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© 2023 Michal Josef Špaček
+© 2023-2024 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
